<?php

/**
 * @version   1.8 February 9, 2017
 * @author    RocketTheme, LLC http://www.rockettheme.com
 * @copyright Copyright (C) 2007 - 2017 RocketTheme, LLC
 * @license   http://www.gnu.org/licenses/gpl-2.0.html GNU/GPLv2 only
 */
/*
Plugin Name: RokMicroNews
Plugin URI: http://www.rockettheme.com
Description: RokMicroNews is a MooTools based news slider widget.
Author: RocketTheme, LLC
Version: 1.8
Author URI: http://www.rockettheme.com
License: http://www.gnu.org/licenses/gpl-2.0.html GNU/GPLv2 only
*/

// Define Directory Separator

if (!defined('DS')) {
	define('DS', DIRECTORY_SEPARATOR);
}

// Globals

global $rokmicronews_plugin_path, $rokmicronews_plugin_url, $browser_platform;
if(!is_multisite()) {
	$rokmicronews_plugin_path = dirname($plugin);
} else {
	if(!empty($network_plugin)) {
		$rokmicronews_plugin_path = dirname($network_plugin);
	} else {
		$rokmicronews_plugin_path = dirname($plugin);
	}
}
$rokmicronews_plugin_url = WP_PLUGIN_URL . '/' . basename($rokmicronews_plugin_path);

require(dirname(__FILE__) . '/rokbrowsercheck.php');

$browser_check = new RokBrowserCheck;
$browser_platform = $browser_check->platform;

// Widget

class RokMicroNews extends WP_Widget {

	// RocketTheme RokMicroNews Widget
	// Port by Jakub Baran

	static $plugin_path;
	static $plugin_url;
	static $global_params = array('use_custom_css');

	var $short_name = 'widget-rokmicronews';
	var $long_name = 'RokMicroNews';
	var $description = 'RocketTheme RokMicroNews Widget';
	var $css_classname = 'widget_rokmicronews';
	var $width = 200;
	var $height = 400;

	var $_defaults = array(
		'title' => '',
		'use_custom_css' => '1',
		'catid' => 'uncategorized',
		'ordering' => 'date',
		'content_type' => 'content',
		'article_count' => '3',
		'preview_count' => '200',
		'mouse_type' => 'click',
		'open_type' => '1',
		'navigation_position' => 'right',
		'show_title' => '0',
		'show_readmore' => '1',
		'readmore_label' => 'Read More ...',
		'show_controls' => '1',
		'image' => '1',
		'catch_first_image' => '0',
		'image_generator' => 'default',
		'thumb_width' => '160',
		'thumb_height' => '130',
		'strip_tags' => 'a,i,br',
		'cssclass' => ''
	);

	function init() {
		global $browser_platform;
		
		// Don't show RokMicroNews on iPhone or Android platform
		if($browser_platform != 'iphone' || $browser_platform != 'android') :
			register_widget("RokMicroNews");
		endif;
	}
	
	function rokmicronews_admin_style() {
		global $rokmicronews_plugin_url;
		
		// Load admin side CSS	
		if(is_admin() && substr($_SERVER['PHP_SELF'], '-11', '11') == 'widgets.php') :
			wp_enqueue_style('rokmicronews_admin_css', $rokmicronews_plugin_url . '/admin/rokmicronews-admin.css');
		endif;
	}
	
	function rokmicronews_scripts() {
		global $rokmicronews_plugin_url;	

		$global_option = get_option('widget_rokmicronews_globals');
		
		if($global_option == false) :
			$global_option = array();
		endif;
		
		if (array_key_exists('use_custom_css', $global_option) && $global_option['use_custom_css'] == '0') {
			// Enqueue Styles
			wp_enqueue_style('rokmicronews_css', $rokmicronews_plugin_url . '/tmpl/rokmicronews.css');
		}

		// Enqueue Scripts
		if(!is_admin()) :
			wp_enqueue_script('rokmicronews_js', $rokmicronews_plugin_url . '/tmpl/rokmicronews.js');
		endif;
	}

	function update($new_instance, $old_instance) {
		$global_instance = array();
		foreach (self::$global_params as $param) {
			if (array_key_exists($param, $new_instance)) {
				$global_instance[$param] = $new_instance[$param];
				unset($new_instance[$param]);
			}
		}
		update_option('widget_rokmicronews_globals',$global_instance);

		return $new_instance;
	}

	function get_settings() {
		$global_option = get_option('widget_rokmicronews_globals');
		if($global_option == false) :
			$global_option = array();
		endif;
		$settings = parent::get_settings();
		foreach($settings as $key=>$setting) {
			if (count($setting) > 0) {
				$settings[$key] = array_merge($setting, $global_option);
			}
		}
		return $settings;
	}
	
	function render($args, $instance) {
		global $more, $post, $rokmicronews_plugin_path, $rokmicronews_plugin_url;
		
		$widget_id = $this->number;
		
		ob_start();
		
		// Before Widget
		echo $args['before_widget'];
		
		// Widget Title
		if($instance['title'] != '')
		echo $args['before_title'] . $args['after_title'];
		
		// Query Init
		$catslug = get_category_by_slug($instance['catid']);
		
		$rokmicronews = new WP_Query('cat=' . $catslug->term_id . '&posts_per_page=' . $instance['article_count'] . '&orderby=' . $instance['ordering']);
		
		// Load Layouts	

		if(file_exists(TEMPLATEPATH . '/html/plugins/wp_rokmicronews/default.php')) :	
			require(TEMPLATEPATH . '/html/plugins/wp_rokmicronews/default.php');
		else :
			require($rokmicronews_plugin_path . '/tmpl/default.php'); 
		endif;
		
		wp_reset_query();
		
		// After Widget
		echo $args['after_widget'];
		
		echo ob_get_clean();
	}
	
	function form($instance) {
		global $rokmicronews_plugin_path, $rokmicronews_plugin_url;
		$defaults = $this->_defaults;
		$instance = wp_parse_args((array) $instance, $defaults);
		foreach ($instance as $variable => $value)
		{
			$$variable = self::_cleanOutputVariable($variable, $value);
			$instance[$variable] = $$variable;
		}
		$this->_values = $instance;
		
		$global_option = get_option('widget_rokmicronews_globals');
		$categories = get_terms('category', 'hide_empty=0&orderby=name');
		
		ob_start();
		
		?>
		
		<!-- Begin RokMicroNews Widget Admin -->
		
		<div class="rokmicronews-admin-wrapper">
			<p>
				<label class="rok-tips" data-tips="Adds the widget title." for="<?php echo $this->get_field_id('title'); ?>">
					<?php _e('Title:', 'rokmicronews'); ?>
				</label>
				<input class="widefat" id="<?php echo $this->get_field_id('title'); ?>" name="<?php echo $this->get_field_name('title'); ?>" type="text" value="<?php echo $instance['title']; ?>" />
			</p>
			
			<p>
				<label class="rok-tips" data-tips="If you select yes, the widget will not load it's own CSS file, and you must provide your own." for="<?php echo $this->get_field_id('use_custom_css'); ?>">
					<?php _e('Use Custom CSS:', 'rokmicronews'); ?>
				</label>
				<input id="<?php echo $this->get_field_id('use_custom_css'); ?>0" type="radio" value="0" name="<?php echo $this->get_field_name('use_custom_css'); ?>" <?php if($global_option['use_custom_css'] == '0') echo 'checked="checked"'; ?>/>
				<label for="<?php echo $this->get_field_id('use_custom_css'); ?>0"><?php _e('No', 'rokmicronews'); ?></label>&nbsp;&nbsp;
				<input id="<?php echo $this->get_field_id('use_custom_css'); ?>1" type="radio" value="1" name="<?php echo $this->get_field_name('use_custom_css'); ?>" <?php if($global_option['use_custom_css'] == NULL || $global_option['use_custom_css'] == '1') echo 'checked="checked"'; ?>/>
				<label for="<?php echo $this->get_field_id('use_custom_css'); ?>1"><?php _e('Yes', 'rokmicronews'); ?></label>
			</p>
			
			<p>
				<label class="rok-tips" data-tips="Choose the Category holding posts to display." for="<?php echo $this->get_field_id('catid'); ?>">
					<?php _e('Content Category:', 'rokmicronews'); ?>
				</label>
				<select class="widefat" name="<?php echo $this->get_field_name('catid'); ?>" id="<?php echo $this->get_field_id('catid'); ?>">
					<?php foreach ($categories as $cat) { ?>
						<option value="<?php echo $cat->slug; ?>"<?php if($instance['catid'] == $cat->slug) : echo ' selected="selected"'; endif; ?>><?php echo $cat->name; ?></option>
					<?php } ?>
				</select>
			</p>
			
			<p>
				<label for="<?php echo $this->get_field_id('ordering'); ?>">
					<?php _e('Ordering:', 'rokmicronews'); ?>
				</label>
				<select class="widefat" id="<?php echo $this->get_field_id('ordering'); ?>" name="<?php echo $this->get_field_name('ordering'); ?>">
					<option value="author"<?php selected($instance['ordering'], 'author'); ?>><?php _e('Author', 'rokmicronews'); ?></option>
					<option value="comment_count"<?php selected($instance['ordering'], 'comment_count'); ?>><?php _e('Comment Count', 'rokmicronews'); ?></option>
					<option value="date"<?php selected($instance['ordering'], 'date'); ?>><?php _e('Date', 'rokmicronews'); ?></option>
					<option value="title"<?php selected($instance['ordering'], 'title'); ?>><?php _e('Title', 'rokmicronews'); ?></option>
					<option value="modified"<?php selected($instance['ordering'], 'modified'); ?>><?php _e('Modified', 'rokmicronews'); ?></option>
					<option value="menu_order"<?php selected($instance['ordering'], 'menu_order'); ?>><?php _e('Menu Order', 'rokmicronews'); ?></option>
					<option value="parent"<?php selected($instance['ordering'], 'parent'); ?>><?php _e('Parent', 'rokmicronews'); ?></option>
					<option value="rand"<?php selected($instance['ordering'], 'rand'); ?>><?php _e('Random', 'rokmicronews'); ?></option>
					<option value="id"<?php selected($instance['ordering'], 'id'); ?>>ID</option>
				</select>
			</p>
			
			<p>
				<label class="rok-tips" data-tips="You can change whether to use the posts content or excerpt." for="<?php echo $this->get_field_id('content_type'); ?>">
					<?php _e('Content Type:', 'rokmicronews'); ?>
				</label>
				<select class="widefat" id="<?php echo $this->get_field_id('content_type'); ?>" name="<?php echo $this->get_field_name('content_type'); ?>">
					<option value="content"<?php selected($instance['content_type'], 'content'); ?>><?php _e('Content', 'rokmicronews'); ?></option>
					<option value="excerpt"<?php selected($instance['content_type'], 'excerpt'); ?>><?php _e('Excerpt', 'rokmicronews'); ?></option>
				</select>
			</p>
			
			<p>
				<label class="rok-tips" data-tips="Number of posts to display from the category." for="<?php echo $this->get_field_id('article_count'); ?>">
					<?php _e('Number of Posts:', 'rokmicronews'); ?>
				</label>
				<input class="widefat" id="<?php echo $this->get_field_id('article_count'); ?>" name="<?php echo $this->get_field_name('article_count'); ?>" type="text" value="<?php echo $instance['article_count']; ?>" />
			</p>
			
			<p>
				<label class="rok-tips" data-tips="Length of characters of post to preview." for="<?php echo $this->get_field_id('preview_count'); ?>">
					<?php _e('Preview Length:', 'rokmicronews'); ?>
				</label>
				<input class="widefat" id="<?php echo $this->get_field_id('preview_count'); ?>" name="<?php echo $this->get_field_name('preview_count'); ?>" type="text" value="<?php echo $instance['preview_count']; ?>" />
			</p>
			
			<p>
				<label class="rok-tips" data-tips="Wheter to change news via click or mouseover." for="<?php echo $this->get_field_id('mouse_type'); ?>">
					<?php _e('Navigation Interaction:', 'rokmicronews'); ?>
				</label>
				<select class="widefat" id="<?php echo $this->get_field_id('mouse_type'); ?>" name="<?php echo $this->get_field_name('mouse_type'); ?>">
					<option value="click"<?php selected($instance['mouse_type'], 'click'); ?>><?php _e('Click', 'rokmicronews'); ?></option>
					<option value="mouseenter"<?php selected($instance['mouse_type'], 'mouseenter'); ?>><?php _e('MouseOver', 'rokmicronews'); ?></option>
				</select>
			</p>
			
			<p>
				<label class="rok-tips" data-tips="How you want the MicroNews showing up at the very first load." for="<?php echo $this->get_field_id('open_type'); ?>">
					<?php _e('First Load Status:', 'rokmicronews'); ?>
				</label>
				<select class="widefat" id="<?php echo $this->get_field_id('open_type'); ?>" name="<?php echo $this->get_field_name('open_type'); ?>">
					<option value="1"<?php selected($instance['open_type'], '1'); ?>><?php _e('Expanded', 'rokmicronews'); ?></option>
					<option value="0"<?php selected($instance['open_type'], '0'); ?>><?php _e('Collapsed', 'rokmicronews'); ?></option>
				</select>
			</p>
			
			<p>
				<label class="rok-tips" data-tips="Position of the navigation." for="<?php echo $this->get_field_id('navigation_position'); ?>">
					<?php _e('Navigation Position:', 'rokmicronews'); ?>
				</label>
				<select class="widefat" id="<?php echo $this->get_field_id('navigation_position'); ?>" name="<?php echo $this->get_field_name('navigation_position'); ?>">
					<option value="left"<?php selected($instance['navigation_position'], 'left'); ?>><?php _e('Left', 'rokmicronews'); ?></option>
					<option value="right"<?php selected($instance['navigation_position'], 'right'); ?>><?php _e('Right', 'rokmicronews'); ?></option>
				</select>
			</p>
			
			<p>
				<label class="rok-tips" data-tips="Select whether to show the posts titles." for="<?php echo $this->get_field_id('show_title'); ?>">
					<?php _e('Show Post Title:', 'rokmicronews'); ?>
				</label>
				<input id="<?php echo $this->get_field_id('show_title'); ?>0" type="radio" value="0" name="<?php echo $this->get_field_name('show_title'); ?>" <?php if($instance['show_title'] == '0') echo 'checked="checked"'; ?>/>
				<label for="<?php echo $this->get_field_id('show_title'); ?>0"><?php _e('No', 'rokmicronews'); ?></label>&nbsp;&nbsp;
				<input id="<?php echo $this->get_field_id('show_title'); ?>1" type="radio" value="1" name="<?php echo $this->get_field_name('show_title'); ?>" <?php if($instance['show_title'] == '1') echo 'checked="checked"'; ?>/>
				<label for="<?php echo $this->get_field_id('show_title'); ?>1"><?php _e('Yes', 'rokmicronews'); ?></label>
			</p>
			
			<p>
				<label class="rok-tips" data-tips="Whether to show the full post view link." for="<?php echo $this->get_field_id('show_readmore'); ?>">
					<?php _e('Show "Read More":', 'rokmicronews'); ?>
				</label>
				<input id="<?php echo $this->get_field_id('show_readmore'); ?>0" type="radio" value="0" name="<?php echo $this->get_field_name('show_readmore'); ?>" <?php if($instance['show_readmore'] == '0') echo 'checked="checked"'; ?>/>
				<label for="<?php echo $this->get_field_id('show_readmore'); ?>0"><?php _e('No', 'rokmicronews'); ?></label>&nbsp;&nbsp;
				<input id="<?php echo $this->get_field_id('show_readmore'); ?>1" type="radio" value="1" name="<?php echo $this->get_field_name('show_readmore'); ?>" <?php if($instance['show_readmore'] == '1') echo 'checked="checked"'; ?>/>
				<label for="<?php echo $this->get_field_id('show_readmore'); ?>1"><?php _e('Yes', 'rokmicronews'); ?></label>
			</p>
			
			<p>
				<label class="rok-tips" data-tips="Change the label of the button that takes you to the full view of post." for="<?php echo $this->get_field_id('readmore_label'); ?>">
					<?php _e('"Read More" Label:', 'rokmicronews'); ?>
				</label>
				<input class="widefat" id="<?php echo $this->get_field_id('readmore_label'); ?>" name="<?php echo $this->get_field_name('readmore_label'); ?>" type="text" value="<?php echo $instance['readmore_label']; ?>" />
			</p>
			
			<p>
				<label class="rok-tips" data-tips="Show or Hide move and collapse control buttons." for="<?php echo $this->get_field_id('show_controls'); ?>">
					<?php _e('Show Controls:', 'rokmicronews'); ?>
				</label>
				<input id="<?php echo $this->get_field_id('show_controls'); ?>0" type="radio" value="0" name="<?php echo $this->get_field_name('show_controls'); ?>" <?php if($instance['show_controls'] == '0') echo 'checked="checked"'; ?>/>
				<label for="<?php echo $this->get_field_id('show_controls'); ?>0"><?php _e('No', 'rokmicronews'); ?></label>&nbsp;&nbsp;
				<input id="<?php echo $this->get_field_id('show_controls'); ?>1" type="radio" value="1" name="<?php echo $this->get_field_name('show_controls'); ?>" <?php if($instance['show_controls'] == '1') echo 'checked="checked"'; ?>/>
				<label for="<?php echo $this->get_field_id('show_controls'); ?>1"><?php _e('Yes', 'rokmicronews'); ?></label>
			</p>
			
			<p>
				<label class="rok-tips" data-tips="Select whether to show the thumbnail." for="<?php echo $this->get_field_id('image'); ?>">
					<?php _e('Show Thumbnail:', 'rokmicronews'); ?>
				</label>
				<input id="<?php echo $this->get_field_id('image'); ?>0" type="radio" value="0" name="<?php echo $this->get_field_name('image'); ?>" <?php if($instance['image'] == '0') echo 'checked="checked"'; ?>/>
				<label for="<?php echo $this->get_field_id('image'); ?>0"><?php _e('No', 'rokmicronews'); ?></label>&nbsp;&nbsp;
				<input id="<?php echo $this->get_field_id('image'); ?>1" type="radio" value="1" name="<?php echo $this->get_field_name('image'); ?>" <?php if($instance['image'] == '1') echo 'checked="checked"'; ?>/>
				<label for="<?php echo $this->get_field_id('image'); ?>1"><?php _e('Yes', 'rokmicronews'); ?></label>
			</p>
			
			<p>
				<label class="rok-tips" data-tips="If enabled the first image found in post will be shown." for="<?php echo $this->get_field_id('catch_first_image'); ?>">
					<?php _e('Catch First Image:', 'rokmicronews'); ?>
				</label>
				<input id="<?php echo $this->get_field_id('catch_first_image'); ?>0" type="radio" value="0" name="<?php echo $this->get_field_name('catch_first_image'); ?>" <?php if($instance['catch_first_image'] == '0') echo 'checked="checked"'; ?>/>
				<label for="<?php echo $this->get_field_id('catch_first_image'); ?>0"><?php _e('No', 'rokmicronews'); ?></label>&nbsp;&nbsp;
				<input id="<?php echo $this->get_field_id('catch_first_image'); ?>1" type="radio" value="1" name="<?php echo $this->get_field_name('catch_first_image'); ?>" <?php if($instance['catch_first_image'] == '1') echo 'checked="checked"'; ?>/>
				<label for="<?php echo $this->get_field_id('catch_first_image'); ?>1"><?php _e('Yes', 'rokmicronews'); ?></label>
			</p>
			
			<p>
				<label class="rok-tips" data-tips="Here you can switch between different thumbnail generators. If you're having problems with first one - you can try the second." for="<?php echo $this->get_field_id('image_generator'); ?>">
					<?php _e('Thumbnail Generator:', 'rokmicronews'); ?>
				</label>
				<select class="widefat" id="<?php echo $this->get_field_id('image_generator'); ?>" name="<?php echo $this->get_field_name('image_generator'); ?>">
					<option value="default"<?php selected($instance['image_generator'], 'default'); ?>><?php _e('Default', 'rokmicronews'); ?></option>
					<option value="phpthumb"<?php selected($instance['image_generator'], 'phpthumb'); ?>><?php _e('PHPThumb', 'rokmicronews'); ?></option>
				</select>
			</p>
			
			<p>
				<label class="rok-tips" data-tips="Dimensions of thumbnail (px)" for="<?php echo $this->get_field_id('thumb_width'); ?>">
					<?php _e('Thumbnail Size (px):', 'rokmicronews'); ?>
				</label>
				<input size="3" id="<?php echo $this->get_field_id('thumb_width'); ?>" name="<?php echo $this->get_field_name('thumb_width'); ?>" type="text" value="<?php echo $instance['thumb_width']; ?>" /> x
				<input size="3" id="<?php echo $this->get_field_id('thumb_height'); ?>" name="<?php echo $this->get_field_name('thumb_height'); ?>" type="text" value="<?php echo $instance['thumb_height']; ?>" />
			</p>
			
			<p>
				<label class="rok-tips" data-tips="HTML tags to allow from the content. Separated by comma, no spaces." for="<?php echo $this->get_field_id('strip_tags'); ?>">
					<?php _e('Allowed HTML Tags:', 'rokmicronews'); ?>
				</label>
				<input class="widefat" id="<?php echo $this->get_field_id('strip_tags'); ?>" name="<?php echo $this->get_field_name('strip_tags'); ?>" type="text" value="<?php echo $instance['strip_tags']; ?>" />
			</p>
			
			<p>
				<label class="rok-tips" data-tips="Extra CSS class that will be added to the wrapping div." for="<?php echo $this->get_field_id('cssclass'); ?>">
					<?php _e('Extra Widget CSS Class:', 'rokmicronews'); ?>
				</label>
				<input class="widefat" id="<?php echo $this->get_field_id('cssclass'); ?>" name="<?php echo $this->get_field_name('cssclass'); ?>" type="text" value="<?php echo $instance['cssclass']; ?>" />
			</p>
			
			<div class="rokmicronews-diag">
				<?php	
					if (extension_loaded('gd') && function_exists('gd_info')) {
						echo '<div class="approved">' . __('GD2 Library Present: ', 'rokmicronews') . __('YES', 'rokmicronews') . '</div>';
					} else {
						echo '<div class="alert">' . __('GD2 Library Present: ', 'rokmicronews') . __('NO', 'rokmicronews') . '</div>';
					}

					if (is_writeable($rokmicronews_plugin_path . '/cache')) {
						echo '<div class="approved">' . __('Cache Dir Writeable: ', 'rokmicronews') . __('YES', 'rokmicronews') . '</div>';
					} else {
						echo '<div class="alert">' . __('Cache Dir Writeable: ', 'rokmicronews') . __('NO', 'rokmicronews') . '</div>';
					}
				?>
			</div>
		</div>
		
		<!-- End RokMicroNews Widget Admin -->
	
		<?php
	
		echo ob_get_clean();
	}
	
	function prepareContent($text, $length = 200, $instance) {
		$tags_option = $instance['strip_tags'];
		
		$tags = explode(",", $tags_option);
		$strip_tags = array();
		for($i = 0; $i < count($tags); $i++) {
			$strip_tags[$i] = '<'.trim($tags[$i]).'>';
		}
		$tags = implode(',', $strip_tags);
		
		// strips tags won't remove the actual jscript
		$text = preg_replace( "'<script[^>]*>.*?</script>'si", "", $text );
		
		$text = preg_replace( '/{.+?}/', '', $text);
		$text = strip_tags($text, $tags);
		
		// cut off text at word boundary if required
		if (strlen($text) > $length) {
			$text = substr($text, 0, strpos($text, ' ', $length)) . "..." ;
		} 

		return $text;
	}

	function get_first_image() {
		global $post, $posts;
		$first_img = '';
		ob_start();
		ob_end_clean();
		$output = preg_match_all("/\<img.+?src=\"(.+?)\".+?\/>/", $post->post_content, $matches);
		$first_img = $matches[1][0];
		return $first_img;
	}

	/*
	* Resize images dynamically using wp built in functions
	* Victor Teixeira
	*
	* php 5.2+
	*
	* Example of use :
	* 
	* <?php 
	* $thumb = get_post_thumbnail_id(); 
	* $image = rokmicronews_resize( $thumb, '', 140, 110, true );
	* ?>
	* <img src="<?php echo $image[url]; ?>" width="<?php echo $image[width]; ?>" height="<?php echo $image[height]; ?>" />
	*
	* @param int $attach_id
	* @param string $img_url
	* @param int $width
	* @param int $height
	* @param bool $crop
	* @return array
	*/
	 
	function rokmicronews_resize( $attach_id = null, $img_url = null, $width, $height, $crop = false ) {
	
		global $rokmicronews_plugin_path, $rokmicronews_plugin_url;
	
		// this is an attachment, so we have the ID
		if ( $attach_id ) {
		
			$image_src = wp_get_attachment_image_src( $attach_id, 'full' );
			$file_path = get_attached_file( $attach_id );
		
		// this is not an attachment, let's use the image url
		} else if ( $img_url ) {
			
			$file_path = parse_url( $img_url );
			$file_path = $_SERVER['DOCUMENT_ROOT'] . $file_path['path'];
			
			//$file_path = ltrim( $file_path['path'], '/' );
			//$file_path = rtrim( ABSPATH, '/' ).$file_path['path'];
			
			$orig_size = @getimagesize( $file_path );
			
			$image_src[0] = $img_url;
			$image_src[1] = $orig_size[0];
			$image_src[2] = $orig_size[1];
		}
		
		$file_info = pathinfo( $file_path );
		$extension = '.'. $file_info['extension'];
	
		// the image path without the extension
		$no_ext_path = $rokmicronews_plugin_path. DS .'cache'. DS .$file_info['filename'];
	
		$cropped_img_path = $no_ext_path.'-'.$width.'x'.$height.$extension;
	
		// checking if the file size is larger than the target size
		// if it is smaller or the same size, stop right here and return
		if ( $image_src[1] > $width || $image_src[2] > $height ) {
	
			// the file is larger, check if the resized version already exists (for $crop = true but will also work for $crop = false if the sizes match)
			if ( file_exists( $cropped_img_path ) ) {
	
				$default_url = str_replace(basename($image_src[0]), basename($cropped_img_path), $image_src[0]);
				$cropped_img_url = str_replace(dirname($image_src[0]), $rokmicronews_plugin_url. DS .'cache', $default_url);
				
				$vt_image = array (
					'url' => $cropped_img_url,
					'width' => $width,
					'height' => $height
				);
				
				return $vt_image;
			}
	
			// $crop = false
			if ( $crop == false ) {
			
				// calculate the size proportionaly
				$proportional_size = wp_constrain_dimensions( $image_src[1], $image_src[2], $width, $height );
				$resized_img_path = $no_ext_path.'-'.$proportional_size[0].'x'.$proportional_size[1].$extension;		
	
				// checking if the file already exists
				if ( file_exists( $resized_img_path ) ) {
				
					$default_url = str_replace( basename( $image_src[0] ), basename( $resized_img_path ), $image_src[0] );
					$resized_img_url = str_replace(dirname($image_src[0]), $rokmicronews_plugin_url. DS .'cache', $default_url);
	
					$vt_image = array (
						'url' => $resized_img_url,
						'width' => $proportional_size[0],
						'height' => $proportional_size[1]
					);
					
					return $vt_image;
				}
			}
	
			// no cache files - let's finally resize it
			$new_img_path = image_resize( $file_path, $width, $height, $crop, '', $rokmicronews_plugin_path. DS .'cache' );
			$new_img_size = getimagesize( $new_img_path );
			$default_url = str_replace( basename( $image_src[0] ), basename( $new_img_path ), $image_src[0] );
			$new_img = str_replace(dirname($image_src[0]), $rokmicronews_plugin_url. DS .'cache', $default_url);
	
			// resized output
			$vt_image = array (
				'url' => $new_img,
				'width' => $new_img_size[0],
				'height' => $new_img_size[1]
			);
			
			return $vt_image;
		}
	
		// default output - without resizing
		$vt_image = array (
			'url' => $image_src[0],
			'width' => $image_src[1],
			'height' => $image_src[2]
		);
		
		return $vt_image;
	}
	
	/********** Bellow here should not need to be changed ***********/

	function __construct() {
		if (empty($this->short_name) || empty($this->long_name)) {
			die("A widget must have a valid type and classname defined");
		}
		$widget_options = array('classname' => $this->css_classname, 'description' => __($this->description));
		$control_options = array('width' => $this->width, 'height' => $this->height);
		parent::__construct($this->short_name, $this->long_name, $widget_options, $control_options);
	}

	function _cleanOutputVariable($variable, $value) {
		if (is_string($value)) {
			return htmlspecialchars($value);
		}
		elseif (is_array($value)) {
			foreach ($value as $subvariable => $subvalue) {
				$value[$subvariable] = self::_cleanOutputVariable($subvariable, $subvalue);
			}
			return $value;
		}
		return $value;
	}

	function _cleanInputVariable($variable, $value) {
		if (is_string($value)) {
			return stripslashes($value);
		}
		elseif (is_array($value)) {
			foreach ($value as $subvariable => $subvalue) {
				$value[$subvariable] = self::_cleanInputVariable($subvariable, $subvalue);
			}
			return $value;
		}
		return $value;
	}

	function widget($args, $instance){
		global $gantry;
		extract($args);
		$defaults = $this->_defaults;
		$instance = wp_parse_args((array) $instance, $defaults);
		foreach ($instance as $variable => $value)
		{
			$$variable = self::_cleanOutputVariable($variable, $value);
			$instance[$variable] = $$variable;
		}
		$this->render($args, $instance);
	}

}

RokMicroNews::$plugin_path = dirname($plugin);
RokMicroNews::$plugin_url = WP_PLUGIN_URL . '/' . basename(RokMicroNews::$plugin_path);

add_action('widgets_init', array('RokMicroNews', 'init'));
add_action('wp_enqueue_scripts', array('RokMicroNews', 'rokmicronews_scripts'));
add_action('admin_enqueue_scripts', array('RokMicroNews', 'rokmicronews_admin_style'));

// Add RokMicroNews meta box

function rokmicronews_add_custom_box() {
	 add_meta_box('rokmicronews_box', 'RokMicroNews', 'rokmicronews_custom_box', 'post', 'normal', 'high');
}

function rokmicronews_custom_box() {
	global $post;
	$image = get_post_meta($post->ID,'_rokmicronews_image',true);	
	echo '<input type="hidden" name="rokmicronews_noncename" id="rokmicronews_noncename" value="' . wp_create_nonce('rt_rokmicronews') . '" />';
	echo '<p>' . __('Please use links only to images that are located on the same server as your WordPress site. If automatic thumbnails aren\'t working for you please check if the <b>cache</b> directory inside of the RokMicroNews plugin dir has proper permissions.', 'rokmicronews') . '<br /><br />';
	echo '<label for="rt_image_box">' . __('Full Image URL:', 'rokmicronews') . '</label> ';
	echo '<input type="text" class="code" value="' . $image . '" id="rt_micronews_box" name="rt_micronews_box" style="width:99%;" /></p>';
}

function rokmicronews_save_data($post_id) {
	 // verify this with nonce because save_post can be triggered at other times
	 if (!wp_verify_nonce($_POST['rokmicronews_noncename'], 'rt_rokmicronews')) return $post_id;
	 
	 // do not save if this is an auto save routine
	 if (defined('DOING_AUTOSAVE') && DOING_AUTOSAVE) return $post_id;

	 $rt_image_box = trim($_POST['rt_micronews_box']);
	 if($rt_image_box != '') :
		 update_post_meta($post_id, '_rokmicronews_image', $rt_image_box);
	 else:
		 delete_post_meta($post_id, '_rokmicronews_image');
	 endif;
}

add_action('admin_menu', 'rokmicronews_add_custom_box');
add_action('save_post', 'rokmicronews_save_data');

// Load Language

load_plugin_textdomain('rokmicronews', false, basename($rokmicronews_plugin_path) . '/languages/');

// MooTools Enqueue Script

add_action('init', 'rokmicronews_mootools_init', -50);

function rokmicronews_mootools_init(){
	global $rokmicronews_plugin_url;
	wp_register_script('mootools.js', $rokmicronews_plugin_url . '/tmpl/mootools.js');
	wp_enqueue_script('mootools.js');
}


?>