/**
 * RokMicroNews
 *
 * @package		Joomla
 * @subpackage	RokMicroNews
 * @copyright Copyright (C) 2009 RocketTheme. All rights reserved.
 * @license http://www.gnu.org/copyleft/gpl.html GNU/GPL, see RT-LICENSE.php
 * @author RocketTheme, LLC
 *
 */

var RokMiN = {};
RokMiN.id = '#rokmicronews';
RokMiN.alt = [];
RokMiN.settings = {};


window.addEvent('load', function() {
	if (!$$(RokMiN.id).length) {
		for (var id in RokMiN.settings) {
			var container = document.id('rokmicronews');
			if (!container) container = new Element('div', {id: 'rokmicronews'}).inject(document.id(id).getParent().getParent(), 'before');

			container.adopt(document.id(id).getParent('.rokmicronews-surround'));
		}
	}

	var rokmicronews = new RokMicroNews(RokMiN.id);
});

// Do not edit below!
var RokMicroNews = new Class({
	Implements: [Options],
	version: '0.1',
	options: {
		radius: 4,
		startHeight: 300,
		mousetype: 'click'
	},

	initialize: function(element, options) {
		this.container = $$(element)[0];
		if (!this.container) return false;

		this.setOptions(options);

		this.cookie = new Hash.Cookie('RokMicroNews', {duration: 30});

		this.selection = (Browser.ie) ? 'selectstart' : 'mousedown';
		var stopEvent = function(e) {
			e.stop();
		};

		var dummy = new Element('div', {'class': 'micronews-drop', 'styles': {'position': 'absolute', 'display': 'none'}}).inject(document.body), self = this;

		this.blocks = $$('.micronews');
		this.collapse = this.container.getElements('.collapse, .expand');
		this.surrounds = this.container.getElements('.rokmicronews-surround');
		this.micro = {};
		this.status = {};
		this.sortables = this.doSortable(dummy);
		if (this.cookie.getLength()) this.restore();

		this.blocks.each(function(block, i) {
			var index = i;
			this.micro[block.id] = {};

			var micro = this.micro[block.id], height = 0, listHeight;

			micro.headline = block.getElement('.micronews-headline');
			micro.wrapper = block.getElement('.micronews-article-wrapper');
			micro.articles = block.getElement('.micronews-articles').setStyle('height', this.options.startHeight);
			micro.entries = block.getElements('.micronews-articles .entry');
			micro.entriesFx = [];
			micro.mousetype = RokMiN.settings[block.id].mousetype;
			micro.inner = block.getElement('.micronews-inner').setStyle('overflow', 'hidden');
			micro.listWrapper = block.getElement('.micronews-list');
			micro.list = block.getElements('.micronews-list ul li');
			micro.fx = new Fx.Tween(micro.inner, {wait: false, duration: 300});
			micro.open = (typeof this.status[block.id] == 'undefined') ? RokMiN.settings[block.id].open : this.status[block.id];

			listHeight = micro.listWrapper.getSize().y;
			micro.entries.each(function(entry, i) {
				if (i) entry.setStyle('visibility', 'hidden');
				micro.entriesFx.push(new Fx.Tween(entry, {link: 'cancel', duration: 400,
					onStart: function(){
						if (!this.from[0].value) entry.setStyle('visibility', 'visible');
					},
					onComplete: function(){
						if (!this.to[0].value) entry.setStyle('visibility', 'hidden');
						else entry.setStyle('visibility', 'visible');
					}
				}).set('opacity', (!i) ? 1 : 0));
				entry.setStyles({
					'position': 'absolute',
					'top': micro.articles.getStyle('padding-top').toInt(),
					'left': micro.articles.getStyle('padding-left').toInt(),
					'right': micro.articles.getStyle('padding-right').toInt()
				});
				var entryHeight = entry.getSize().y;
				if (entryHeight > height) height = entryHeight;
			});

			micro.list.each(function(list, i) {
				if (!i) list.addClass('active');
				list.addEvent(micro.mousetype, function(e) {
					new Event(e).stop();
					micro.entriesFx.each(function(fx) {
						fx.start('opacity', 0);
					});
					micro.entriesFx[i].start('opacity', 1);
					micro.list.removeClass('active');
					list.addClass('active');
				});
			}, this);

			micro.articles.setStyles({
				'position': 'relative',
				'height': Math.max(listHeight, height)
			});

			micro.height = micro.inner.getSize().y;

			if (this.collapse.length) {
				document.id(this.collapse[index]).addEvent('click', function(e) {
					e.stop();
					if (micro.open) {
						self.show(0, block.id);
						this.removeClass('collapse').addClass('expand');
					} else {
						self.show(micro.height, block.id);
						this.removeClass('expand').addClass('collapse');
					}

					self.store();
				});
			}

			if (!micro.open) {
				this.show(0, block.id);
				this.collapse[i].removeClass('collapse').addClass('expand');
			}

		}, this);

		if (!this.cookie.getLength()) this.store();

		return this;

	},

	show: function(amount, id) {
		switch(amount) {
			case 0:
				this.micro[id].open = false;
				this.micro[id].fx.start('height', 0);
				break;
			default:
				this.micro[id].open = true;
				this.micro[id].fx.start('height', amount);
		}

		return this;
	},

	doSortable: function(dummy) {
		var movers = this.container.getElements('.mover').setStyle('cursor', 'move'), self = this;

		if (movers.length == 1) {
			movers[0].dispose();
			return false;
		}
		return new Sortables(this.container, {
			handle: '.mover',
			opacity: 0.5,
			clone: true,
			constrain: true,
			onStart: function(element, ghost){
				var sizes = element.getCoordinates();
				var border = dummy.getStyle('border-width').toInt() || 0;

				ghost.inject(self.container);
				ghost.setStyles({
					'opacity': 0.7,
					'left': self.container.getParent().getStyle('padding-left').toInt(),
					'width': sizes.width,
					'height': sizes.height
				});
				this.tmp = new Element('div', {
					'class': 'micronews-drop',
					'styles': {
						'width': sizes.width - (border * 2),
						'height': sizes.height - (border * 2),
						'-moz-border-radius': self.options.radius + 'px',
						'-webkit-border-radius': self.options.radius + 'px'
					}
				}).inject(element, 'before');
				element.setStyle('display', 'none');
			},
			onSort: function(element, ghost) {
				this.tmp.inject(element, 'before');
			},
			onComplete: function(element){
				element.setStyles({'display': '', 'opacity': 1});
				if (this.tmp) this.tmp.dispose();
				self.store();
			}
		});
	},

	store: function() {
		var save = {};
		if (this.sortables) {
			var serialize = this.sortables.serialize(function(el){
				return el.getElement('.micronews').id;
			});

			serialize.each(function(block, i) {
				var micro = this.micro[block];
				save[i] = {
					'open': micro.open,
					'element': block
				};
			}, this);
		} else {
			var hash = new Hash(this.micro);
			hash.each(function(value, key) {
				save[0] = {
					'open': value.open,
					'element': key
				};
			});
		}

		this.cookie.extend(save);

		return this;
	},

	restore: function() {
		var hash = new Hash(this.cookie.getClean()), first = false;
		for (i = 0, l = hash.getLength(); i < l; i++) {
			var el = document.id(hash.get(i).element);
			if (el) {
				el = el.getParent('.rokmicronews-surround');
				if (!i) {
					first = el;
					if (first) el.inject(this.container, 'top');
				} else {
					var next = el.getPrevious();
					if (next) {
						next.inject(first ? first : el.getPrevious(), 'after');
						first = el;
					}
				}

				this.status[hash.get(i).element] = hash.get(i).open;
			}
		}

		return this;
	}
});
